import { Injectable } from '@nestjs/common';
import { BaseManager } from '../base.manager';

export abstract class BaseUpdateManager<Entity> extends BaseManager {
  protected dataId: string;
  protected result: Entity;
  protected duplicateColumn: string[];
  abstract get entityTarget(): any;

  setData(id: string, entity: Entity): void {
    this.dataId = id;
    this.data = entity;
  }

  async prepareData(): Promise<void> {
    Object.assign(this.data, {
      editor_id: this.user.id,
      editor_name: this.user.name,
      updated_at: new Date().getTime(),
    });
  }

  async process(): Promise<void> {
    this.result = await this.dataService.update(
      this.queryRunner,
      this.entityTarget,
      { id: this.dataId },
      this.data,
    );
  }

  async getResult(): Promise<Entity> {
    return await this.dataService.getOneByOptions({
      where: {
        id: this.dataId,
      },
    });
  }
}
