import { Injectable } from "@nestjs/common";
import { CreateUserPrivilegeManager } from "./managers/create-user-privilege.manager";
import { UserPrivilegeDataService } from "../../data/service/user-privilege-data.service";
import { UserPrivilegeEntity } from "../entities/user-privilege.entity";
import { DeleteUserPrivilegeManager } from "./managers/delete-user-privilege.manager";
import { UpdateUserPrivilegeManager } from "./managers/update-user-privilege.manager";
import { BaseDataTransactionOrchestrator } from "src/core/modules/domain/usecase/orchestrators/base-data-transaction.orchestrator";
import { ActiveUserPrivilegeManager } from "./managers/active-user-privilege.manager";
import { InactiveUserPrivilegeManager } from "./managers/inactive-user-privilege.manager";
import { ConfirmUserPrivilegeManager } from "./managers/confirm-user-privilege.manager";
import { STATUS } from "src/core/strings/constants/base.constants";

@Injectable()
export class UserPrivilegeDataOrchestrator extends BaseDataTransactionOrchestrator<UserPrivilegeEntity> {

    constructor(
        private createManager: CreateUserPrivilegeManager,
        private updateManager: UpdateUserPrivilegeManager,
        private deleteManager: DeleteUserPrivilegeManager,
        private activeManager: ActiveUserPrivilegeManager,
        private confirmManager: ConfirmUserPrivilegeManager,
        private inactiveManager: InactiveUserPrivilegeManager,
        private serviceData: UserPrivilegeDataService,
    ) {
        super();
    }

    async create(data): Promise<UserPrivilegeEntity> {
        this.createManager.setData(data);
        this.createManager.setService(this.serviceData);
        await this.createManager.execute()
        return this.createManager.getResult();
    }

    async update(dataId, data): Promise<UserPrivilegeEntity> {
        this.updateManager.setData(dataId, data);
        this.updateManager.setService(this.serviceData);
        await this.updateManager.execute();
        return this.updateManager.getResult();
    }

    async delete(dataId): Promise<String> {
        this.deleteManager.setData(dataId);
        this.deleteManager.setService(this.serviceData);
        await this.deleteManager.execute();
        return this.deleteManager.getResult();
    }

    async active(dataId): Promise<String> {
        this.activeManager.setData(dataId, STATUS.ACTIVE)
        this.activeManager.setService(this.serviceData);
        await this.activeManager.execute();
        return this.activeManager.getResult();
    }

    async confirm(dataId): Promise<String> {
        this.confirmManager.setData(dataId, STATUS.ACTIVE)
        this.confirmManager.setService(this.serviceData);
        await this.confirmManager.execute();
        return this.confirmManager.getResult();
    }

    async inactive(dataId): Promise<String> {
        this.inactiveManager.setData(dataId, STATUS.INACTIVE)
        this.inactiveManager.setService(this.serviceData);
        await this.inactiveManager.execute();
        return this.inactiveManager.getResult();
    }
}